#### Stated preferences for the colours, smells and sounds of biodiversity  ###############
# Project: ERC Relate Project. Work Package 5
# Author: Dr Peter King (p.king1@leeds.ac.uk)
# Function: To plot Figure B1 the effect of impairments on WTP
# Notes: should work
# Last Edited: 28/09/2024
# - double-checking post R2
# - updating sessioninfo()


# ************************************************************************
#### Section 0: Setup and estimate models ####
# ************************************************************************


## sessionInfo() for Replicability ------------------------------------------------------------------------------
# R version 4.4.1 (2024-06-14 ucrt)
# Platform: x86_64-w64-mingw32/x64
# Running under: Windows 11 x64 (build 22631)
# Matrix products: default
# locale:
#   [1] C
# system code page: 65001
# time zone: Europe/London
# tzcode source: internal
# attached base packages:
#   [1] stats     graphics  grDevices utils     datasets  methods   base
# other attached packages:
#   [1] ggdist_3.3.2       stringi_1.8.4      sf_1.0-16
# [4] udunits2_0.13.2.1  PostcodesioR_0.3.1 geosphere_1.5-18
# [7] psych_2.4.3        readxl_1.4.3       coin_1.4-3
# [10] survival_3.7-0     Rfast_2.1.0        RcppParallel_5.1.7
# [13] RcppZiggurat_0.1.6 Rcpp_1.0.12        lubridate_1.9.3
# [16] forcats_1.0.0      stringr_1.5.1      purrr_1.0.2
# [19] readr_2.1.5        tidyr_1.3.1        tibble_3.2.1
# [22] tidyverse_2.0.0    RColorBrewer_1.1-3 data.table_1.15.4
# [25] here_1.0.1         mded_0.1-2         reshape2_1.4.4
# [28] ggridges_0.5.6     ggplot2_3.5.1      magrittr_2.0.3
# [31] dplyr_1.1.4        apollo_0.3.3
# loaded via a namespace (and not attached):
#   [1] DBI_1.2.3            mnormt_2.1.1         sandwich_3.1-0
# [4] rlang_1.1.4          multcomp_1.4-25      e1071_1.7-14
# [7] matrixStats_1.3.0    compiler_4.4.1       systemfonts_1.1.0
# [10] vctrs_0.6.5          quantreg_5.98        pkgconfig_2.0.3
# [13] backports_1.5.0      mcmc_0.9-8           utf8_1.2.4
# [16] tzdb_0.4.0           miscTools_0.6-28     ragg_1.3.2
# [19] MatrixModels_0.5-3   modeltools_0.2-23    Deriv_4.1.3
# [22] broom_1.0.6          parallel_4.4.1       R6_2.5.1
# [25] Rsolnp_1.16          car_3.1-2            cellranger_1.1.0
# [28] numDeriv_2016.8-1.1  zoo_1.8-12           rngWELL_0.10-9
# [31] Matrix_1.7-0         splines_4.4.1        timechange_0.3.0
# [34] tidyselect_1.2.1     rstudioapi_0.16.0    abind_1.4-5
# [37] maxLik_1.5-2.1       codetools_0.2-20     lattice_0.22-6
# [40] plyr_1.8.9           withr_3.0.0          coda_0.19-4.1
# [43] RSGHB_1.2.2          units_0.8-5          proxy_0.4-27
# [46] pillar_1.9.0         carData_3.0-5        KernSmooth_2.23-24
# [49] stats4_4.4.1         distributional_0.4.0 generics_0.1.3
# [52] rprojroot_2.0.4      sp_2.1-4             truncnorm_1.0-9
# [55] hms_1.1.3            munsell_0.5.1        scales_1.3.0
# [58] randtoolbox_2.0.4    class_7.3-22         glue_1.7.0
# [61] tools_4.4.1          SparseM_1.83         mvtnorm_1.2-5
# [64] grid_4.4.1           MCMCpack_1.7-0       libcoin_1.0-10
# [67] colorspace_2.1-0     nlme_3.1-165         cli_3.6.3
# [70] textshaping_0.4.0    fansi_1.0.6          gtable_0.3.5
# [73] rstatix_0.7.2        digest_0.6.35        classInt_0.4-10
# [76] bgw_0.1.3            TH.data_1.1-2        farver_2.1.2
# [79] lifecycle_1.0.4      httr_1.4.7           MASS_7.3-61


## Libraries ------------------------------------------------------------------------------
# install.packages("data.table",repos="http://cran.us.r-project.org")
# options(scipen=90)
library(apollo)
library(tidyverse)
library(dplyr)
library(magrittr)
library(mded)
library(here)
library(data.table)
library(Rfast)


# ************************************************************************
#### Section 1: Setup parallelisation and benchmarking ####
# ************************************************************************



## **************************
## Import Survey Data
## **************************
## Use step three and add unconditionals rather than use Step4.csv with conditionals
here()
Winter <-
  here("OtherData", "Winter_dataframe_Step4.csv") %>% fread() %>% data.frame()
## For various reasons I'm dropping the existing WTP to re-add it here
## This makes fixing the rest of the code easier
Winter <- Winter[, 1:217]

## Truncate to have same number of rows as in the models
Winter <-
  Winter[!is.na(Winter$MilesDistance),] ## Drop missing distances
Winter <-
  Winter[!is.na(Winter$Overall),] ## Drop respondents not completing BIOWELL



## **************************
## Import WTP
## **************************

## This is the WTP from the model itself:
### Note: 1711 rows (one per respondent), 9001 variables (1000 per attribute level)
### Note: added all four datasets here so you can choose
# WTP <- here("CEoutput/ModelTwo", "Winter_MXL_ModelTwo_ConWTP.csv") %>% fread() %>% data.frame()
WTP <-
  here("CEoutput/ModelTwo",
       "Winter_MXL_ModelTwo_AllCorrelations_ConWTP.csv") %>% fread() %>% data.frame()


## If the conditionals are imported then run this to recover only useful variables
WTP <-
  WTP[WTP %>% select(-ends_with(c(".ID", ".post.sd"))) %>% colnames()] %>% data.frame()



WTP <-
  bind_cols(
    "ColourHigh" = WTP$b_Colour2.post.mean,
    "ColourMedium" = WTP$b_Colour.post.mean,
    "SmellHigh" = WTP$b_Smell2.post.mean,
    "SmellMedium" = WTP$b_Smell.post.mean,
    "SoundHigh" = WTP$b_Sound2.post.mean,
    "SoundMedium" = WTP$b_Sound.post.mean,


    "HearingIssues" = Winter$HearingIssues ,
    "SightIssues" = Winter$SightIssues ,
    "SmellIssues" = Winter$SmellIssues ,
    "Impairment" = Winter$Impairment
  )

# ************************************************************************
#### Section 2: Define useful variables ####
# ************************************************************************


## I want this order on the plot:
Names <- c(
  "ColourHigh",
  "ColourMedium",
  "SmellHigh",
  "SmellMedium",
  "SoundHigh",
  "SoundMedium"
)



Labels <-
  Names %>% gsub(pattern = "Decomposition",
                 replacement = "decomposition") %>%
  gsub(pattern = "Medium", replacement = "\nmedium") %>%
  gsub(pattern = "High", replacement = "\nhigh") %>%
  gsub(pattern = "Colour", replacement = "Colours:") %>%
  gsub(pattern = "Smell", replacement = "Smells:") %>%
  gsub(pattern = "Sound", replacement = "Sounds:") %>%
  gsub(pattern = "Deadwood", replacement = "Deadwood:") %>%
  c()



## I got these from RColorBrewer but adding specifically here to
### (a) see the colours in the console with new RStudio,
### (b) make scale_fill_manual() easier
Colours <- c("#C6DBEF",
             "#C6DBEF",
             "#08306B",
             "#08306B",
             "#6BAED6",
             "#6BAED6")

## Update all text sizes here for consistency
TextSize <- 12

TextSetup <- element_text(size = TextSize,
                          colour = "black",
                          family = "serif")

## Label grouping variable
Impairments <- c(0, 1)


LegendLabels <- c(
  paste0(
    "No impairment\n (N = ",
    Winter %>% filter(Impairment == 0) %>% nrow(),
    ")"
  ),
  paste0(
    "Impairment\n (N = ",
    Winter %>% filter(Impairment == 1) %>% nrow(),
    ")"
  )
)

# ***************************************************************************
#### Section 3: Create Data ####
# ***************************************************************************


PlotData <- WTP %>%
  pivot_longer(1:6) %>%
  mutate("YMIN" = quantile(value, c(0.025)),
         "YMAX" = quantile(value, c(0.975)))

## THis is an important step for the correct plot order!
PlotData$name <-
  factor(PlotData$name,
         levels = unique(PlotData$name))


PlotData$Selected <-
  ifelse(
    PlotData$name %in% c("ColourHigh", "ColourMedium"),
    PlotData$SightIssues,
    ifelse(
      PlotData$name %in% c("SoundHigh", "SoundMedium"),
      PlotData$HearingIssues,
      ifelse(
        PlotData$name %in% c("SmellHigh", "SmellMedium"),
        PlotData$SmellIssues,
        PlotData$Impairment
      )
    )
  )


# ************************************************************************
#### Section 3: Create Plot ####
# ************************************************************************



## Using this version now!
Figure2_Impairments <-
  PlotData %>% ggplot(aes(
    x = value,
    y = rev(name),
    fill = Impairment %>% as.factor()
  )) +

  stat_boxplot(geom = "errorbar",
               width = 0.25,
               position = position_dodge(width = 0.75)) +

  geom_boxplot(outlier.shape = NA) +

  theme_bw() +

  geom_vline(xintercept = 0, alpha = 1) +

  scale_x_continuous(name = "Marginal WTP (GBP) in local council tax, per household, per annum",
                     breaks = seq(-50, 50, 5)) +

  scale_y_discrete(name = "Attribute and level", labels = rev(Labels)) +

  scale_fill_manual(
    name = "Impairment:",
    values = RColorBrewer::brewer.pal(9, "Blues")[c(6, 9)],
    label = LegendLabels,
    guide = guide_legend(reverse = FALSE)
  ) +

  theme(
    legend.position = "bottom",
    legend.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    legend.text = TextSetup,
    legend.title = TextSetup,
    axis.text.x = TextSetup,
    axis.text.y = TextSetup,
    axis.title.y = TextSetup,
    axis.title.x = TextSetup
  ) +
  coord_cartesian(xlim = c(-10, 30))


# ggdist::stat_histinterval(normalize = "groups",
#                           slab_linewidth = 0.5,
#                           slab_colour = "black",
#                           outline_bars = TRUE,
#                           position = "dodge",
#                           height = 0.90,
#                           scale  = 0.75) +


# ************************************************************************
#### Section 3: Export Plot ####
# ************************************************************************

FigureB1_Impairments <- Figure2_Impairments


ggsave(
  FigureB1_Impairments,
  device = "png",
  filename = paste0(
    here(),
    "/OtherOutput/Figures/",
    "FigureB1_Impairments_Boxplot.png"
  ),
  width = 20,
  height = 15,
  units = "cm",
  dpi = 500
)


# **********************************************************************************
#### END OF SCRIPT ####
## Next step: 23_Winter_FigureB2_VisitFrequency.R
# **********************************************************************************
